*******>Bugfix 6:

Authors:  Terry Lang and Demetri Moustakas

Program:  dock

Description:  This fix addresses a number of issues.  In general, if an orientation
  cannot be generated or scored for some reason, the program terminates with no 
  informative output.  To address orientation generation problems, dock now throws 
  an error message if no orientations are generated in the course of the run.  To 
  address scoring problems, we have added a new field to the DOCKMol class that will 
  maintain a string with information about the state of the calculation.  This string 
  is modified upon the successful completion of scoring to include the score breakdown.  
  Finally, the specific scoring problem in which poses that extend beyond the grid
  are not scored properly, has been addressed.  Instead, poses that extend beyond the 
  grid are ignored in scoring and dock throws an error.    

Fix:  Make the following changes to the files src/base_mpi.cpp, src/base_score.h, 
  src/conf_gen.cpp, src/conf_gen.h, src/dockmol.cpp, src/dockmol.h, 
  src/library_file.cpp, src/library_file.h, src/score.cpp, src/score.h, 
  src/simplex.cpp, and src/simplex.h
 
Index: base_mpi.cpp
===================================================================
RCS file: /usr/local/cvsroot/dock/src/base_mpi.cpp,v
retrieving revision 1.1
diff -c -r1.1 base_mpi.cpp
*** base_mpi.cpp	25 Mar 2005 18:50:48 -0000	1.1
--- base_mpi.cpp	4 Jun 2005 01:57:03 -0000
***************
*** 72,77 ****
--- 72,82 ----
  		*ostr << mol.atom_active_flags[i] << endl;
  	for(i=0;i<mol.num_bonds;i++)
  		*ostr << mol.bond_active_flags[i] << endl;
+ 
+ 	//write the scoring information 
+ 	*ostr << mol.current_score << endl;
+ 	*ostr << mol.current_data << endl;
+ 
  /*****
  	// write the AMBER atom type information
  	*ostr << mol.amber_at_assigned << endl;
***************
*** 243,248 ****
--- 248,260 ----
  		mol.bond_active_flags[i] = (tmp_int == 1) ? true : false;
  //		sscanf(line, "%d", &(mol.bond_active_flags[i]));
  	}
+ 
+ 	// read the scoring information
+ 	istr->getline(line, 1000);
+ 	sscanf(line, "%d", &(mol.current_score));
+ 	istr->getline(line, 1000);
+ 	sscanf(line, "%s", &(mol.current_data));
+ 
  /*****
  	// read the AMBER atom type information
  	istr->getline(line, 1000);
Index: base_score.h
===================================================================
RCS file: /usr/local/cvsroot/dock/src/base_score.h,v
retrieving revision 1.1
diff -c -r1.1 base_score.h
*** base_score.h	25 Mar 2005 18:50:48 -0000	1.1
--- base_score.h	4 Jun 2005 01:57:03 -0000
***************
*** 24,30 ****
  
  	/* Generic Function Definitions */
  	virtual	bool	compute_score(DOCKMol &) { return true; };
! 	virtual	string	output_score_summary() { return ""; };
  	float			return_current_score() {return current_score;};
  
  	/* Interpolation fxns */
--- 24,30 ----
  
  	/* Generic Function Definitions */
  	virtual	bool	compute_score(DOCKMol &) { return true; };
! 	virtual string	output_score_summary(float) { return ""; };
  	float			return_current_score() {return current_score;};
  
  	/* Interpolation fxns */
Index: conf_gen.cpp
===================================================================
RCS file: /usr/local/cvsroot/dock/src/conf_gen.cpp,v
retrieving revision 1.3
diff -c -r1.3 conf_gen.cpp
*** conf_gen.cpp	10 May 2005 00:08:43 -0000	1.3
--- conf_gen.cpp	4 Jun 2005 01:57:03 -0000
***************
*** 1669,1676 ****
  	switch (method) {
  
  		case 0:
! 			num_conformers = 1;
! 			last_conformer = false;
  			break;
  
  		case 1:
--- 1669,1676 ----
  	switch (method) {
  
  		case 0:
! 			more_anchors = true;
! 			last_conformer = true;
  			break;
  
  		case 1:
***************
*** 1692,1700 ****
  	switch (method) {
  
  		case 0:
! 			if(num_conformers>0)
  				return_val = true;
! 			else
  				return_val = false;
  			break;
  
--- 1692,1701 ----
  	switch (method) {
  
  		case 0:
! 			if(more_anchors){
! 				more_anchors = false;
  				return_val = true;
! 			}else
  				return_val = false;
  			break;
  
***************
*** 1727,1738 ****
  			}
  
  			if(more_orients){
! 				num_conformers = 1;
! 				last_conformer = false;
  				return_val = true;
  			}else
  				if(last_conformer){
! 					num_conformers = 1;
  					return_val = true;
  				}else
  					return_val = false;
--- 1728,1740 ----
  			}
  
  			if(more_orients){
! 				more_anchors = true;
! 				last_conformer = true;
  				return_val = true;
  			}else
  				if(last_conformer){
! 					more_anchors = true;
! 					last_conformer = false;
  					return_val = true;
  				}else
  					return_val = false;
***************
*** 1778,1786 ****
  	switch (method) {
  
  		case 0:
! 			last_conformer = true;
! 			if(num_conformers>0){
! 				num_conformers--;
  				return_val = true;
  			}else
  				return_val = false;
--- 1780,1788 ----
  	switch (method) {
  
  		case 0:
! 			if(more_anchors){
! 				more_anchors = false;
! 				last_conformer = true;
  				return_val = true;
  			}else
  				return_val = false;
Index: conf_gen.h
===================================================================
RCS file: /usr/local/cvsroot/dock/src/conf_gen.h,v
retrieving revision 1.2
diff -c -r1.2 conf_gen.h
*** conf_gen.h	10 May 2005 00:08:43 -0000	1.2
--- conf_gen.h	4 Jun 2005 01:57:03 -0000
***************
*** 246,252 ****
  	bool						flexible_ligand;
  	bool						last_conformer;
  	int							method;
! 	int							num_conformers;
  
  	void						input_parameters(Parameter_Reader &parm);
  	void						initialize();
--- 246,252 ----
  	bool						flexible_ligand;
  	bool						last_conformer;
  	int							method;
! 	bool						more_anchors;
  
  	void						input_parameters(Parameter_Reader &parm);
  	void						initialize();
Index: dockmol.cpp
===================================================================
RCS file: /usr/local/cvsroot/dock/src/dockmol.cpp,v
retrieving revision 1.1
diff -c -r1.1 dockmol.cpp
*** dockmol.cpp	25 Mar 2005 18:50:48 -0000	1.1
--- dockmol.cpp	4 Jun 2005 01:57:03 -0000
***************
*** 218,223 ****
--- 218,226 ----
  	target.amber_bt_assigned = original.amber_bt_assigned;
  	target.chem_types_assigned = original.chem_types_assigned;
  
+ 	target.current_score = original.current_score;
+ 	target.current_data = original.current_data;
+ 
  //	target.use_internal_energy = original.use_internal_energy;
  //	target.att_exp = original.att_exp;
  //	target.rep_exp = original.rep_exp;
***************
*** 533,538 ****
--- 536,543 ----
  	num_active_atoms = 0;
  	num_active_bonds = 0;
  	score_text_data = "";
+ 	current_score = 0.0;
+ 	current_data = "ERROR:  Conformation could not be scored by DOCK.\n";
  }
  
  /*************************************/
Index: dockmol.h
===================================================================
RCS file: /usr/local/cvsroot/dock/src/dockmol.h,v
retrieving revision 1.1
diff -c -r1.1 dockmol.h
*** dockmol.h	25 Mar 2005 18:50:48 -0000	1.1
--- dockmol.h	4 Jun 2005 01:57:03 -0000
***************
*** 73,78 ****
--- 73,82 ----
  	float				*gb_hawkins_radius;
  	float				*gb_hawkins_scale;
  
+ 	// General scoring info
+ 	float				current_score;
+ 	string				current_data;
+ 
  	// Neighbor lists
  	INTVec				*neighbor_list;
  //	bool				*ie_neighbor_list;
Index: library_file.cpp
===================================================================
RCS file: /usr/local/cvsroot/dock/src/library_file.cpp,v
retrieving revision 1.1
diff -c -r1.1 library_file.cpp
*** library_file.cpp	25 Mar 2005 18:50:48 -0000	1.1
--- library_file.cpp	4 Jun 2005 01:57:03 -0000
***************
*** 505,510 ****
--- 505,513 ----
  
    rank_list_highest_energy = 0.0;
    rank_list_highest_pos = -1;
+ 
+   read_success = false;
+ 
  }
  
  /************************************************/
***************
*** 657,668 ****
  
    if(!USE_MPI) { // single proc code
  
! 	  write_scored_poses();
! 
! 	  // pose ranking code
! 	  ranked_poses.clear();
! 	  high_position = 0;
! 	  high_score = 0.0;
  
  	  if(read_mol(mol)) {
  
--- 660,673 ----
  
    if(!USE_MPI) { // single proc code
  
! 	  if(read_success){
! 		if(ranked_poses.size() > 0) {
! 			write_scored_poses();
! 		}else{
! 			cout << endl << "-----------------------------------" << endl;
! 			cout << "ERROR:  Could not find valid orientation!" << endl;
! 		}
! 	  }
  
  	  if(read_mol(mol)) {
  
***************
*** 673,678 ****
--- 678,685 ----
  		  if(calc_rmsd)
  			  submit_rmsd_reference(mol);
  
+ 		  read_success = true;
+ 
  		  return true;
  	  } else {
  
***************
*** 700,705 ****
--- 707,713 ----
  						  if(mol_branches.size() > 0)
  							  continue_mols = true;
  
+ 						  read_success = true;
  					  } else {
  						  continue_mols = false;
  					  }
***************
*** 727,733 ****
  				  num_orients = stats[1];
  				  num_confs = stats[2];
  
! 				  write_scored_poses();
  
  			  } // End receive mol code
  
--- 735,748 ----
  				  num_orients = stats[1];
  				  num_confs = stats[2];
  
! 				  if(read_success){
! 						if(ranked_poses.size() > 0) {
! 								write_scored_poses();
! 						}else{
! 							cout << endl << "-----------------------------------" << endl;
! 							cout << "ERROR:  Could not find valid orientation!" << endl;
! 						}
! 				  }
  
  			  } // End receive mol code
  
***************
*** 837,858 ****
    int		i;
    float		max_score;
    int		max_position;
  
    if(score.use_score) {
! 	  score.compute_secondary_score(mol);
! 	  current_score = score.return_secondary_score();
! 	  current_data  = score.secondary_score->output_score_summary();
    } else {
! 	  current_score = 0.0;
! 	  current_data = "";
    }
  
    // Multi-pose output
    if(ranked_poses.size() < num_scored_poses) {
  	  // Add the molecule
  	  ranked_poses.push_back(tmp_rankmol);
! 	  ranked_poses[ranked_poses.size()-1].score = current_score;
! 	  ranked_poses[ranked_poses.size()-1].data = current_data;
  	  copy_molecule(ranked_poses[ranked_poses.size()-1].mol, mol);
  
  	  // find position with the highest score
--- 852,875 ----
    int		i;
    float		max_score;
    int		max_position;
+   bool		success;
  
    if(score.use_score) {
! 	  success = score.compute_secondary_score(mol);
! 	  if(success){
! 		  mol.current_data = score.secondary_score->output_score_summary(mol.current_score);
! 	  }
    } else {
! 	  mol.current_score = 0.0;
! 	  mol.current_data = "";
    }
  
    // Multi-pose output
    if(ranked_poses.size() < num_scored_poses) {
  	  // Add the molecule
  	  ranked_poses.push_back(tmp_rankmol);
! 	  ranked_poses[ranked_poses.size()-1].score = mol.current_score;
! 	  ranked_poses[ranked_poses.size()-1].data = mol.current_data;
  	  copy_molecule(ranked_poses[ranked_poses.size()-1].mol, mol);
  
  	  // find position with the highest score
***************
*** 867,877 ****
  	  high_score = max_score;
  	  high_position = max_position;
  
!   } else if (current_score < high_score) {
  
  	  // add mol to the high position
! 	  ranked_poses[high_position].data = current_data;
! 	  ranked_poses[high_position].score = current_score;
  	  copy_molecule(ranked_poses[high_position].mol, mol);
  
  	  // find position with the highest score
--- 884,894 ----
  	  high_score = max_score;
  	  high_position = max_position;
  
!   } else if (mol.current_score < high_score) {
  
  	  // add mol to the high position
! 	  ranked_poses[high_position].data = mol.current_data;
! 	  ranked_poses[high_position].score = mol.current_score;
  	  copy_molecule(ranked_poses[high_position].mol, mol);
  
  	  // find position with the highest score
***************
*** 903,910 ****
  
    if((!USE_MPI)||(is_master_node())) {
  
- 	  if(ranked_poses.size() > 0) {
- 
  		// sort ranked_poses here
  		sort(ranked_poses.begin(), ranked_poses.end());
  
--- 920,925 ----
***************
*** 968,974 ****
  		high_position = 0;
  		high_score = 0.0;
  
- 	  }
    }
  
  }
--- 983,988 ----
***************
*** 1041,1047 ****
  }
  
  /************************************************/
! void Library_File::old_submit_scored_pose(DOCKMol &mol, Master_Score &score) {
    float		current_score = 0.0;
    string	current_data = "";
    char		score_convert[100];
--- 1055,1061 ----
  }
  
  /************************************************/
! /*void Library_File::old_submit_scored_pose(DOCKMol &mol, Master_Score &score) {
    float		current_score = 0.0;
    string	current_data = "";
    char		score_convert[100];
Index: library_file.h
===================================================================
RCS file: /usr/local/cvsroot/dock/src/library_file.h,v
retrieving revision 1.1
diff -c -r1.1 library_file.h
*** library_file.h	25 Mar 2005 18:50:48 -0000	1.1
--- library_file.h	4 Jun 2005 01:57:03 -0000
***************
*** 49,54 ****
--- 49,56 ----
    bool				write_conformers;
    bool				write_scored_ligands;
  
+   bool				read_success;
+ 
    bool				rank_ligands;
    vector<SCOREMol>	ranked_list;
    int				max_ranked;
Index: score.cpp
===================================================================
RCS file: /usr/local/cvsroot/dock/src/score.cpp,v
retrieving revision 1.2
diff -c -r1.2 score.cpp
*** score.cpp	5 Apr 2005 00:27:05 -0000	1.2
--- score.cpp	4 Jun 2005 01:57:03 -0000
***************
*** 246,274 ****
  bool Energy_Score::compute_score(DOCKMol &mol) {
    float		vdw_val, es_val, total;
    int		atom;
  
    total = vdw_val = es_val = 0.0;
  
    if(energy_score == 1) {
  
  	  for(atom=0;atom<mol.num_atoms;atom++) {
  
  		  if(mol.atom_active_flags[atom]) {
  
- 			  if(check_box_boundaries(mol.x[atom], mol.y[atom], mol.z[atom])) {
  				  find_grid_neighbors(mol.x[atom], mol.y[atom], mol.z[atom]);
  
  				  vdw_val += ((vdwA[mol.amber_at_id[atom]] * interpolate(avdw)) - (vdwB[mol.amber_at_id[atom]] * interpolate(bvdw)))*vdw_scale;
  				  es_val  += mol.charges[atom] * interpolate(es) * es_scale;
! 			  } else {
! 				  // hack to penalize out-of-box mols
! 				  current_score = 10000;
! 				  vdw_component = 5000;
! 				  es_component = 5000;
! 				  return false;
! 			  }
  
- 		  }
  
  	  }
  
--- 246,279 ----
  bool Energy_Score::compute_score(DOCKMol &mol) {
    float		vdw_val, es_val, total;
    int		atom;
+   string	text;
+   char		line[1000];
+ 
  
    total = vdw_val = es_val = 0.0;
  
    if(energy_score == 1) {
  
+ 	  //check to see if molecule is inside grid box
+ 	  for(atom=0;atom<mol.num_atoms;atom++){
+ 			if(!check_box_boundaries(mol.x[atom], mol.y[atom], mol.z[atom])){
+ 				mol.current_score = 0.0;
+ 				sprintf(line, "ERROR:  Conformation could not be scored by DOCK.\nConformation not completely within grid box.\n");
+ 				mol.current_data = line;
+ 				return false;
+ 			}
+ 	  }
+ 
  	  for(atom=0;atom<mol.num_atoms;atom++) {
  
  		  if(mol.atom_active_flags[atom]) {
  
  				  find_grid_neighbors(mol.x[atom], mol.y[atom], mol.z[atom]);
  
  				  vdw_val += ((vdwA[mol.amber_at_id[atom]] * interpolate(avdw)) - (vdwB[mol.amber_at_id[atom]] * interpolate(bvdw)))*vdw_scale;
  				  es_val  += mol.charges[atom] * interpolate(es) * es_scale;
! 			  } 
  
  
  	  }
  
***************
*** 277,283 ****
  	  vdw_component = vdw_val;
  	  es_component = es_val;
  
! 	  current_score = total;
  
  //	  add_score_to_mol(mol, "Energy Score", total);
  
--- 282,288 ----
  	  vdw_component = vdw_val;
  	  es_component = es_val;
  
! 	  mol.current_score = total;
  
  //	  add_score_to_mol(mol, "Energy Score", total);
  
***************
*** 287,298 ****
  }
  
  /************************************************/
! string Energy_Score::output_score_summary() {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## Energy Score:%20f\n##########%14s%20f\n##########%14s%20f\n##########\n", current_score,"vdw:", vdw_component, "es:", es_component);
  	  text = line;
  
  	  return text;
--- 292,304 ----
  }
  
  /************************************************/
! string Energy_Score::output_score_summary(float score) {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 
! 	  sprintf(line, "########## Energy Score:%20f\n##########%14s%20f\n##########%14s%20f\n##########\n", score,"vdw:", vdw_component, "es:", es_component);
  	  text = line;
  
  	  return text;
***************
*** 453,464 ****
  }
  
  /************************************************/
! string Continuous_Energy_Score::output_score_summary() {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## Energy Score:%20f\n##########%14s%20f\n##########%14s%20f\n##########\n", current_score,"vdw:", vdw_component, "es:", es_component);
  	  text = line;
  
  	  return text;
--- 459,470 ----
  }
  
  /************************************************/
! string Continuous_Energy_Score::output_score_summary(float score) {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## Energy Score:%20f\n##########%14s%20f\n##########%14s%20f\n##########\n", score,"vdw:", vdw_component, "es:", es_component);
  	  text = line;
  
  	  return text;
***************
*** 571,581 ****
    float		cnt_score;
    int		vdw_threshold;
    int		atom;
  
    cnt_score = 0;
    vdw_threshold = 0;
  
!   if(contact_score == 1) {
  
  	  for(atom=0;atom<mol.num_atoms;atom++) {
  
--- 577,597 ----
    float		cnt_score;
    int		vdw_threshold;
    int		atom;
+   char		line[1000];
  
    cnt_score = 0;
    vdw_threshold = 0;
  
!   if(contact_score == 1) {	  
! 	  
! 	  for(atom=0;atom<mol.num_atoms;atom++){
! 			if(!check_box_boundaries(mol.x[atom], mol.y[atom], mol.z[atom])){
! 				mol.current_score = 0.0;
! 				sprintf(line, "ERROR:  Conformation could not be scored by DOCK.\nConformation not completely within grid box.\n");
! 				mol.current_data = line;
! 				return false;
! 			}
! 	  }
  
  	  for(atom=0;atom<mol.num_atoms;atom++) {
  
***************
*** 583,590 ****
  
  			  if(mol.atom_active_flags[atom]) {
  
- 				  if(check_box_boundaries(mol.x[atom], mol.y[atom], mol.z[atom])) {
- 
  					  find_grid_neighbors(mol.x[atom], mol.y[atom], mol.z[atom]);
  
  					  vdw_threshold = NINT( 10 * mol.amber_at_radius[atom] );
--- 599,604 ----
***************
*** 595,606 ****
  						  cnt_score += (float)cnt[nearest_neighbor];
  					  }
  
- 				  } else {
- 					  // hack to penalize out-of-box molecules
- 					  current_score = 10000;
- 					  return false;
- 				  }
- 
  			  }
  
  		  }
--- 609,614 ----
***************
*** 615,626 ****
  }
  
  /************************************************/
! string Contact_Score::output_score_summary() {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## Contact Score:%19f\n##########\n",current_score);
  	  text = line;
  
  	  return text;
--- 623,634 ----
  }
  
  /************************************************/
! string Contact_Score::output_score_summary(float score) {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## Contact Score:%19f\n##########\n",score);
  	  text = line;
  
  	  return text;
***************
*** 784,795 ****
  }
  
  /************************************************/
! string GB_Pairwise::output_score_summary() {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## GB/SA Score:%21f\n##########%13s%21f\n##########%13s%21f\n##########%13s%21f\n##########%13s%21f\n##########\n", current_score, "vdw:", vdw_component, "gb:", gb_component, "sa:", sa_component, "del_SAS_hp:", del_SAS_hp);
  
  	  text = line;
  
--- 792,803 ----
  }
  
  /************************************************/
! string GB_Pairwise::output_score_summary(float score) {
    string	text;
    char		line[1000];
  
    if(use_score) {
! 	  sprintf(line, "########## GB/SA Score:%21f\n##########%13s%21f\n##########%13s%21f\n##########%13s%21f\n##########%13s%21f\n##########\n", score, "vdw:", vdw_component, "gb:", gb_component, "sa:", sa_component, "del_SAS_hp:", del_SAS_hp);
  
  	  text = line;
  
Index: score.h
===================================================================
RCS file: /usr/local/cvsroot/dock/src/score.h,v
retrieving revision 1.1
diff -c -r1.1 score.h
*** score.h	25 Mar 2005 18:50:48 -0000	1.1
--- score.h	4 Jun 2005 01:57:03 -0000
***************
*** 59,65 ****
  	void			read_nrg_grid();
  	bool			compute_score(DOCKMol &mol);
  	void			init_vdw_energy(AMBER_TYPER &);
! 	string			output_score_summary();
  
  };
  
--- 59,65 ----
  	void			read_nrg_grid();
  	bool			compute_score(DOCKMol &mol);
  	void			init_vdw_energy(AMBER_TYPER &);
! 	string			output_score_summary(float);
  
  };
  
***************
*** 90,96 ****
  	void			initialize(AMBER_TYPER &);
  	void			init_vdw_energy(AMBER_TYPER &typer);
  	bool			compute_score(DOCKMol &);
! 	string			output_score_summary();
  
  };
  
--- 90,96 ----
  	void			initialize(AMBER_TYPER &);
  	void			init_vdw_energy(AMBER_TYPER &typer);
  	bool			compute_score(DOCKMol &);
! 	string			output_score_summary(float);
  
  };
  
***************
*** 116,122 ****
  
  	void			read_cnt_grid();
  	bool			compute_score(DOCKMol &mol);
! 	string			output_score_summary();
  
  };
  
--- 116,122 ----
  
  	void			read_cnt_grid();
  	bool			compute_score(DOCKMol &mol);
! 	string			output_score_summary(float);
  
  };
  
***************
*** 244,250 ****
  	void			initialize(AMBER_TYPER &typer, int argc, char **argv);
  	bool			compute_score(DOCKMol &mol);
  	float			return_current_score() { return current_score; };
! 	string			output_score_summary();
  
  	void			read_gb_receptor_grid();
  	float			get_gb_solvation_score(DOCKMol &mol);
--- 244,250 ----
  	void			initialize(AMBER_TYPER &typer, int argc, char **argv);
  	bool			compute_score(DOCKMol &mol);
  	float			return_current_score() { return current_score; };
! 	string			output_score_summary(float);
  
  	void			read_gb_receptor_grid();
  	float			get_gb_solvation_score(DOCKMol &mol);
Index: simplex.cpp
===================================================================
RCS file: /usr/local/cvsroot/dock/src/simplex.cpp,v
retrieving revision 1.1
diff -c -r1.1 simplex.cpp
*** simplex.cpp	25 Mar 2005 18:50:48 -0000	1.1
--- simplex.cpp	4 Jun 2005 01:57:03 -0000
***************
*** 348,353 ****
--- 348,354 ----
  	int			step_count;
  	int			fail_count;
  	bool		accept_flag;
+ 	bool		score_success;
  
  	float		ave_score;
  	int			ave_count;
***************
*** 455,462 ****
  			for(i=0;i<size+1;i++) {
  				for(j=0;j<size;j++)
  					vertex[j] = p[i][j];
! 
! 				y[i] = simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size);
  			}
  
  			delta = y[0];
--- 456,468 ----
  			for(i=0;i<size+1;i++) {
  				for(j=0;j<size;j++)
  					vertex[j] = p[i][j];
! 				//check if simplex point is valid
! 				if(simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size)){
! 					y[i] = tmp_mol.current_score;
! 				}else{
! 				    optimum = ref_mol.current_score;
! 					return optimum;
! 				}
  			}
  
  			delta = y[0];
***************
*** 480,486 ****
  			}
  
  			// evaluate the fxn at the reflected point
! 			ypr = simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size);
  
  			if(ypr <= y[ilo]) {
  
--- 486,498 ----
  			}
  
  			// evaluate the fxn at the reflected point
! 			//check if fxn valid
! 			if(simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size)){
! 				ypr = tmp_mol.current_score;
! 			}else{
! 				optimum = ref_mol.current_score;
! 				return optimum;
! 			}
  
  			if(ypr <= y[ilo]) {
  
***************
*** 488,494 ****
  				for(i=0;i<size;i++)
  					vertex[i] = prr[i] = (1.0 + alpha) * pr[i] - alpha*pbar[i];
  
! 				yprr = simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size);
  
  				if(yprr < y[ilo]) {
  					// The additional extrap succeeded, and replaces the high point
--- 500,512 ----
  				for(i=0;i<size;i++)
  					vertex[i] = prr[i] = (1.0 + alpha) * pr[i] - alpha*pbar[i];
  
! 				//check if new point is valid
! 				if(simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size)){
! 					yprr = tmp_mol.current_score;
! 				}else{
! 					optimum = ref_mol.current_score;
! 					return optimum;
! 				}
  
  				if(yprr < y[ilo]) {
  					// The additional extrap succeeded, and replaces the high point
***************
*** 522,528 ****
  				for(i=0;i<size;i++)
  					vertex[i] = prr[i] = beta * p[ihi][i] + (1.0 - beta) * pbar[i];
  
! 				yprr = simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size);
  
  				if(yprr < y[ihi]) {
  					// contraction is an improvement, so accept it
--- 540,551 ----
  				for(i=0;i<size;i++)
  					vertex[i] = prr[i] = beta * p[ihi][i] + (1.0 - beta) * pbar[i];
  
! 				if(simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size)){
! 					yprr = tmp_mol.current_score;
! 				}else{
! 					optimum = ref_mol.current_score;
! 					return optimum;
! 				}
  
  				if(yprr < y[ihi]) {
  					// contraction is an improvement, so accept it
***************
*** 541,548 ****
  							for(j=0;j<size;j++) {
  								vertex[j] = p[i][j] = pr[j] = 0.5 * (p[i][j] + p[ilo][j]);
  							}
! 
! 							y[i] = simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size);
  						}
  				}
  
--- 564,576 ----
  							for(j=0;j<size;j++) {
  								vertex[j] = p[i][j] = pr[j] = 0.5 * (p[i][j] + p[ilo][j]);
  							}
! 							//check if low point is valid
! 							if(simplex_score(score, ref_mol, tmp_mol, vertex, trans_step_size, rot_step_size, tors_step_size)){
! 								y[i] = tmp_mol.current_score;
! 							}else{
! 								optimum = ref_mol.current_score;
! 								return optimum;
! 							}
  						}
  				}
  
***************
*** 690,706 ****
  }
  
  /******************************************************/
! float Simplex_Minimizer::simplex_score(Base_Score &score, DOCKMol &ref_mol, DOCKMol &tmp_mol, FLOATVec &vertex, float trans_step_size, float rot_step_size, float tors_step_size) {
  	FLOATVec		new_vec;
! 	float			return_val;
! 
  	copy_crds(tmp_mol, ref_mol);
  	scale_simplex_vector(new_vec, vertex, trans_step_size, rot_step_size, tors_step_size);
  	vector_to_dockmol(tmp_mol, new_vec);
  
! 	score.compute_score(tmp_mol);
! 	return_val = score.return_current_score();
! 
  	return return_val;
  }
  
--- 718,732 ----
  }
  
  /******************************************************/
! bool Simplex_Minimizer::simplex_score(Base_Score &score, DOCKMol &ref_mol, DOCKMol &tmp_mol, FLOATVec &vertex, float trans_step_size, float rot_step_size, float tors_step_size) { 
  	FLOATVec		new_vec;
! 	bool			return_val;
  	copy_crds(tmp_mol, ref_mol);
  	scale_simplex_vector(new_vec, vertex, trans_step_size, rot_step_size, tors_step_size);
  	vector_to_dockmol(tmp_mol, new_vec);
  
! 	return_val = score.compute_score(tmp_mol);
! 	
  	return return_val;
  }
  
Index: simplex.h
===================================================================
RCS file: /usr/local/cvsroot/dock/src/simplex.h,v
retrieving revision 1.1
diff -c -r1.1 simplex.h
*** simplex.h	25 Mar 2005 18:50:48 -0000	1.1
--- simplex.h	4 Jun 2005 01:57:03 -0000
***************
*** 70,76 ****
  	void			initialize();
  	void			minimize(Base_Score &, DOCKMol &, FLOATVec &, int, float, int, float, float, float, float);
  	float			simplex_minimize(Base_Score &, DOCKMol &, FLOATVec &, int, float, float, float, float);
! 	float			simplex_score(Base_Score &, DOCKMol &, DOCKMol &, FLOATVec &, float, float, float);
  	void			scale_simplex_vector(FLOATVec &, FLOATVec &, float, float, float);
  	void			vector_to_dockmol(DOCKMol &, FLOATVec &);
  	void			minimize_rigid_anchor(DOCKMol &, Master_Score &);
--- 70,76 ----
  	void			initialize();
  	void			minimize(Base_Score &, DOCKMol &, FLOATVec &, int, float, int, float, float, float, float);
  	float			simplex_minimize(Base_Score &, DOCKMol &, FLOATVec &, int, float, float, float, float);
! 	bool			simplex_score(Base_Score &, DOCKMol &, DOCKMol &, FLOATVec &, float, float, float);
  	void			scale_simplex_vector(FLOATVec &, FLOATVec &, float, float, float);
  	void			vector_to_dockmol(DOCKMol &, FLOATVec &);
  	void			minimize_rigid_anchor(DOCKMol &, Master_Score &);
